/* Load the two Census ACS sequence data files: Estimates (Est) and Margin of Error(MOE) */
/* for a given sequence that contains one or more desired tables and combine them. */
/* See "Sequence_Number_and_Table_Number_Lookup.xls" to get sequence number for the desired table */

options sysprintfont=("Courier New" 8) leftmargin=0.75in nocenter;

/* Specify ACS sequence number and number of variables: */
%let seqnum=049;  * The sequence number of files that contain the table you want (3 digits);
%let lastvar=226;  * Number of variables in the sequence needed (position of the last variable);
/* Example: seqnum 049 and lastvar 226 for table C17002 (Ratio of Income to Poverty Level) */

/* Specify data path here for portability: */
%let pathin=J:\Census_Stuff\ACS2011_5yr\DownloadCenter_2_giant_files\Tracts_Block_Groups_Only\;
%let pathsas=J:\Census_Stuff\ACS2011_5yr\;
%let pathpdf=J:\Census_Stuff\ACS2011_5yr\SASRpts\;
%let acsendyear=2011;

%let obslimit=;
/* %let obslimit=obs=10000; /* For debugging */

libname CensSAS "&pathsas.SASData";
ods pdf file="&pathpdf.SAS11_DataStats_&seqnum._tracts.pdf";

/* Create a dataset with the state abbreviations and Fips codes */

proc sort data=sashelp.zipcode nodupkey out=statetbl;
   by state statecode;
run;

data statetbl;
   set statetbl;
   keep state statecode;
   if state <= 56 or state = 72; /* Just the 50 states, DC, and Puerto Rico */
run;

%macro readEst;
/* Read in state ACS Est File */
options NOSOURCE; /* Suppress generated source from IMPORT */
PROC IMPORT DATAFILE="&pathin.e&acsendyear.5&statem.0&seqnum.000.txt "
    OUT=tempEst DBMS=CSV REPLACE ;
   getnames=no;
   DATAROW=1;
run;
options SOURCE;
proc datasets nolist force;
   append out=EstSeq&seqnum data=tempEst;
   quit;
run;
%mend readEst;

%macro readMOE;
/* Read in a state ACS MOE File */
options NOSOURCE; /* Suppress generated source from IMPORT */
PROC IMPORT DATAFILE="&pathin.m&acsendyear.5&statem.0&seqnum.000.txt "
    OUT=tempMOE DBMS=CSV REPLACE ;
   getnames=no;
   DATAROW=1;
run;
options SOURCE;
proc datasets nolist force;
   append out=MOESeq&seqnum data=tempMOE;
   quit;
run;
%mend readMOE;

/* For debugging, just do AL */
/* %let statem=AL; */
/* %readEst; */
/* %readMOE; */

%macro allstates;
   %do j=1 %to 52;
   /* Read the state table 52 times, find the jth record, */
   /*   and call readgeo using the statecode of jth record. */
   data _null_;
      set statetbl;
      if _n_=&j;
      call symputx('statem', statecode);
      %readEst;
      %readMOE;
   run;
   %end;
%mend allstates;

/* Before we start, delete any previous versions */
proc datasets nolist;
   delete EstSeq&seqnum;
   delete MOESeq&seqnum;
   quit;
run;

%allstates;

/* Clean up key variables and make consistent with Geo files */
data EstSeq&seqnum._2;
   set EstSeq&seqnum.;
   var3=upcase(var3);
   keep var3 var5 var6 var7-var&lastvar;
   rename var3=STUSAB;
   rename var5=SEQUENCE;
   rename var6=LOGRECNO;
run;
data MOESeq&seqnum._2;
   set MOESeq&seqnum.;
   var3=upcase(var3);
   keep var3 var5 var6 var7-var&lastvar;
   rename var3=STUSAB;
   rename var5=SEQUENCE;
   rename var6=LOGRECNO;
run;

/* Rename MOE variables */
%macro rename_mvars;
proc datasets library=work nolist;
   modify MOESeq&seqnum._2;
   rename %do i=7 %to &lastvar;
   VAR&i=MVAR&i.
   %end;
   ;
   run; quit;
%mend rename_mvars;
%rename_mvars;

/* Remove any duplicate records (there should not be any)*/
proc sort data=EstSeq&seqnum._2 noduprecs out=EstSeq&seqnum._nodups;
   by STUSAB SEQUENCE LOGRECNO;
run;
proc sort data=MOESeq&seqnum._2 noduprecs out=MOESeq&seqnum._nodups;
   by STUSAB SEQUENCE LOGRECNO;
run;

/* Merge the Est and MOE files */
proc sort data=EstSeq&seqnum._nodups;
   by STUSAB SEQUENCE LOGRECNO;
run;
proc sort data=MOESeq&seqnum._nodups;
   by STUSAB SEQUENCE LOGRECNO;
run;
data AllEstMOE_Seq&seqnum;
   merge EstSeq&seqnum._nodups (in=inEst) MOESeq&seqnum._nodups (in=inMOE);
   by STUSAB SEQUENCE LOGRECNO;
run;

/* Sort by state and LOGRECNO  */
proc sort data=CensSAS.AllGeo;
   by STUSAB LOGRECNO;
run;
proc sort data=AllEstMOE_Seq&seqnum;
   by STUSAB LOGRECNO;
run;

/* Merge the Geo and data files */
data CensSAS.AllData_Seq&seqnum._tracts;
   merge CensSAS.AllGeo (in=inGeo) AllEstMOE_Seq&seqnum (in=inEstMOE);
   by STUSAB LOGRECNO;
   if inGeo & inEstMOE; /* Only keep the matches */
run;

/* Stats from the merged ACS Geo and Data file */

proc freq data = CensSAS.AllData_Seq&seqnum._tracts;
    table STATE*STUSAB / list missing;
    table SUMLEV*GEOCOMP / list;
run;

/* Number of distinct values for each variable */
ods select nlevels;
proc freq data=CensSAS.AllData_Seq&seqnum._tracts nlevels;
   table STUSAB;
run;

ods pdf close;
