/* Merge extracted data and calculate derived values and MOEs for tract attributes */
/* Also merge data from the subject tables with direct percentages and MOEs */
/* Also calculate CVs from values and MOEs */

options sysprintfont=("Courier New" 8) leftmargin=0.75in nocenter;

/* Specify data path here for portability: */
%let pathsas=J:\Census_Stuff\ACS2011_5yr\;
%let pathpdf=J:\Census_Stuff\ACS2011_5yr\SASRpts\;

%let obslimit=;
/* %let obslimit=obs=10000; /* For debugging */

libname CensSAS "&pathsas.SASData";
ods pdf file="&pathpdf.SAS31_Merge_Tract_Attributes.pdf" uniform;

/* options mprint mlogic symbolgen; /* for macro debugging */

/* Macro to calculate the MOE of a sum or difference */
/*   temporary variables: sumdiff1 sumdiff2 sumdiff */
%macro moe_sumdiff (moe1=, moe2=, moesumdiff=);
    sumdiff1_se  = &moe1 / 1.645; /* convert MOE1 to std error */
    sumdiff2_se  = &moe2 / 1.645; /* convert MOE2 to std error */
    sumdiff_se = SQRT((sumdiff1_se**2)+(sumdiff2_se**2));
    &moesumdiff = sumdiff_se * 1.645; /* convert std error to MOE */
%mend moe_sumdiff;

/* Macro to calculate the MOE of a percent */
/*   temporary variables: num_est num_se denom_est denom_se temp1 pct_se  */
%macro moe_pct (estnum=, moenum=, estdenom=, moedenom=, moepct=);
    num_est = &estnum;
    num_se = &moenum / 1.645; /* convert MOE to std error */
    denom_est = &estdenom;
    denom_se  = &moedenom / 1.645; /* convert MOE to std error */
    temp1 = (((num_est**2)/(denom_est**2))*denom_se**2);
    if (num_se**2)-temp1 >= 0 then
         pct_se = (1/denom_est)*SQRT((num_se**2)-temp1);
    else pct_se = (1/denom_est)*SQRT((num_se**2)+temp1);
    &moepct = 100 * pct_se * 1.645; /* convert std error to MOE */
    /* Limit percent MOE to no more than 100% */
    &moepct = MIN(&moepct,100);
%mend moe_pct;

/* Macro to calculate coefficient of variation (CV) */
%macro cvcalc (varname=);
   if (&varname ^= .) and (&varname ^= 0) then
      &varname._CV = (&varname._MOE / 1.645) * 100 / &varname.;
   else &varname._CV = .;
%mend cvcalc;

/* Merge B00001_samps and B01003_totpop and calculate percent sampled */
data Tract_Attributes;
   merge
    CensSAS.Table_B00001_samps_Tract (&obslimit
        drop = MOE_popsamps)
    CensSAS.Table_B01003_totpop_Tract (&obslimit
        keep = StCntyTract Est_tot_pop MOE_tot_pop
        rename = ( Est_tot_pop=Est_totpop MOE_tot_pop=MOE_totpop ) )
    ;
   by StCntyTract;
   if (Popsamps ^= .) and (Est_totpop ^= 0) then Pct_sampled = 100 * Popsamps / Est_totpop;
   LABEL  Pct_sampled = 'Percent sampled';
   FORMAT Pct_sampled 8.3;
run;

/* Add B02001_race and calculate percent non-white */
data Tract_Attributes;
   merge Tract_Attributes
    CensSAS.Table_B02001_race_Tract (&obslimit
        keep = StCntyTract Est_tot_pop MOE_tot_pop Est_white MOE_white
        rename = ( Est_tot_pop=Est_totpop_race MOE_tot_pop=MOE_totpop_race ) );
   by StCntyTract;
   if Est_totpop_race ^= 0 then do;
        Pct_nonwhite = 100 * (Est_totpop_race - Est_white) / Est_totpop_race;
        /* First calculate the MOE for the subtraction */
        %moe_sumdiff(moe1=MOE_totpop_race, moe2=MOE_white, moesumdiff=tempdiff_moe);
        /* Now calculate the MOE for the percentage */
        %moe_pct(estnum=Est_totpop_race-Est_white, moenum=tempdiff_moe,
            estdenom=Est_totpop_race, moedenom=MOE_totpop_race, moepct=Pct_nonwhite_MOE);
        %cvcalc(varname=Pct_nonwhite);
        end;
   LABEL    Pct_nonwhite     = 'Percent race not white alone'
            Pct_nonwhite_MOE = 'Percent race not white alone MOE'
            Pct_nonwhite_CV  = 'Percent race not white alone CV'
            ;
   FORMAT   Pct_nonwhite     8.3
            Pct_nonwhite_MOE 8.3
            Pct_nonwhite_CV 10.3
            ;
   DROP num_est num_se denom_est denom_se temp1 pct_se tempdiff_moe
        sumdiff1_se sumdiff2_se sumdiff_se;
run;

/* Add B03002_hisp and calculate percent Hispanic and percent minority */
data Tract_Attributes;
   merge Tract_Attributes
    CensSAS.Table_B03002_hisp_Tract (&obslimit
        keep = StCntyTract Est_tot_pop MOE_tot_pop
            Est_Hisp_tot MOE_Hisp_tot Est_nHisp_white MOE_nHisp_white
        rename = ( Est_tot_pop=Est_totpop_Hisp MOE_tot_pop=MOE_totpop_Hisp ) );
   by StCntyTract;
   if Est_totpop_Hisp ^= 0 then do;
        Pct_Hispanic = 100 * Est_Hisp_tot / Est_totpop_Hisp;
        /* Calculate the MOE for the percentage */
        %moe_pct(estnum=Est_Hisp_tot, moenum=MOE_Hisp_tot,
            estdenom=Est_totpop_Hisp, moedenom=MOE_totpop_Hisp, moepct=Pct_Hispanic_MOE);
        %cvcalc(varname=Pct_Hispanic);
        Pct_minority = 100 * (Est_totpop_Hisp - Est_nHisp_white) / Est_totpop_Hisp;
        /* First calculate the MOE for the subtraction */
        %moe_sumdiff(moe1=MOE_totpop_Hisp, moe2=MOE_nHisp_white, moesumdiff=tempdiff_moe);
        /* Now calculate the MOE for the percentage */
        %moe_pct(estnum=Est_totpop_Hisp-Est_nHisp_white, moenum=tempdiff_moe,
            estdenom=Est_totpop_Hisp, moedenom=MOE_totpop_Hisp, moepct=Pct_minority_MOE);
        %cvcalc(varname=Pct_minority);
        end;
   LABEL    Pct_Hispanic     = 'Percent Hispanic'
            Pct_Hispanic_MOE = 'Percent Hispanic MOE'
            Pct_Hispanic_CV  = 'Percent Hispanic CV'
            Pct_minority     = 'Percent minority (other than non-Hisp white)'
            Pct_minority_MOE = 'Percent minority (other than non-Hisp white) MOE'
            Pct_minority_CV  = 'Percent minority (other than non-Hisp white) CV'
            ;
   FORMAT   Pct_Hispanic     8.3
            Pct_Hispanic_MOE 8.3
            Pct_Hispanic_CV 10.3
            Pct_minority     8.3
            Pct_minority_MOE 8.3
            Pct_minority_CV 10.3
            ;
   DROP num_est num_se denom_est denom_se temp1 pct_se tempdiff_moe
        sumdiff1_se sumdiff2_se sumdiff_se ;
run;

/* Add B05012_forborn and calculate percent foreign born */
data Tract_Attributes;
   merge Tract_Attributes
    CensSAS.Table_B05012_forborn_Tract (&obslimit
        keep = StCntyTract Est_tot_pop MOE_tot_pop Est_forborn MOE_forborn
        rename = ( Est_tot_pop=Est_totpop_forborn MOE_tot_pop=MOE_totpop_forborn ) );
   by StCntyTract;
   if ((Est_totpop_forborn ^= 0) &
        (Est_totpop_forborn ^= .)) then do; /* Foreign born values are missing for Puerto Rico */
        Pct_forborn = 100 * Est_forborn / Est_totpop_forborn;
        /* Calculate the MOE for the percentage */
        %moe_pct(estnum=Est_forborn, moenum=MOE_forborn,
            estdenom=Est_totpop_forborn, moedenom=MOE_totpop_forborn, moepct=Pct_forborn_MOE);
        %cvcalc(varname=Pct_forborn);
        end;
   LABEL    Pct_forborn     = 'Percent foreign born'
            Pct_forborn_MOE = 'Percent foreign born MOE'
            Pct_forborn_CV  = 'Percent foreign born CV'
            ;
   FORMAT   Pct_forborn     8.3
            Pct_forborn_MOE 8.3
            Pct_forborn_CV 10.3
            ;
   DROP num_est num_se denom_est denom_se temp1 pct_se;
run;

/* Add S1501_educ subject table data with percent high school and college */
data Tract_Attributes;
   merge Tract_Attributes
    CensSAS.Table_S1501_educ_Tract (&obslimit
        drop = STATE COUNTY GEO_NAME );
   by StCntyTract;
run;

/* Add B16002_lingiso (keep just the tot_hh varaibles) */
data Tract_Attributes;
   merge Tract_Attributes
    CensSAS.Table_B16002_lingiso_Tract (&obslimit
        keep = StCntyTract Est_tot_hh MOE_tot_hh
        rename = ( Est_tot_hh=Est_tothh_lingiso MOE_tot_hh=MOE_tothh_lingiso ) );
   by StCntyTract;
run;

/* Add S1602_lingiso subject table data with percent linguistically isolated */
data Tract_Attributes;
   merge Tract_Attributes
    CensSAS.Table_S1602_lingiso_Tract (&obslimit
        drop = STATE COUNTY GEO_NAME ) ;
   by StCntyTract;
run;

/* Add B16005_engl and calculate percent non-English */
data Tract_Attributes;
   merge Tract_Attributes
    CensSAS.Table_B16005_engl_Tract (&obslimit
        keep = StCntyTract Est_tot_pop MOE_tot_pop
                Est_nat_Spa_Engnone MOE_nat_Spa_Engnone Est_nat_Ind_Engnone MOE_nat_Ind_Engnone
                Est_nat_API_Engnone MOE_nat_API_Engnone Est_nat_oth_Engnone MOE_nat_oth_Engnone
                Est_for_Spa_Engnone MOE_for_Spa_Engnone Est_for_Ind_Engnone MOE_for_Ind_Engnone
                Est_for_API_Engnone MOE_for_API_Engnone Est_for_oth_Engnone MOE_for_oth_Engnone
        rename = ( Est_tot_pop=Est_totpop_engl MOE_tot_pop=MOE_totpop_engl ) );
   by StCntyTract;
   zeroest = 0; /* flag to indicate a zero estimate has beed used for a series of sums */
   if Est_totpop_engl ^= 0 then do;
        /* Linguistic isolation */
        temp_noEngl = Est_nat_Spa_Engnone + Est_nat_Ind_Engnone +
                      Est_nat_API_Engnone + Est_nat_oth_Engnone +
                      Est_for_Spa_Engnone + Est_for_Ind_Engnone +
                      Est_for_API_Engnone + Est_for_oth_Engnone;
        Pct_noEngl = 100 * (temp_noEngl) / Est_totpop_engl;
        if (Est_nat_Spa_Engnone + Est_nat_Ind_Engnone) = 0 then do; /* if both estimates are zero */
            tempsum_moe = MOE_nat_Spa_Engnone; /* use only one zero MOE */
            zeroest = 1; /* set the zero estimate flag */
            end;
        else do;
            %moe_sumdiff(moe1=MOE_nat_Spa_Engnone, moe2=MOE_nat_Ind_Engnone, moesumdiff=tempsum_moe);
            if (Est_nat_Spa_Engnone = 0) or (Est_nat_Ind_Engnone = 0) then zeroest = 1;
            end;
        if ((Est_nat_API_Engnone ^= 0) or ((Est_nat_API_Engnone = 0) and (zeroest = 0))) then do;
            %moe_sumdiff(moe1=tempsum_moe, moe2=MOE_nat_API_Engnone, moesumdiff=tempsum_moe);
            if Est_nat_API_Engnone = 0 then zeroest = 1;
            end;
        if ((Est_nat_oth_Engnone ^= 0) or ((Est_nat_oth_Engnone = 0) and (zeroest = 0))) then do;
            %moe_sumdiff(moe1=tempsum_moe, moe2=MOE_nat_oth_Engnone, moesumdiff=tempsum_moe);
            if Est_nat_oth_Engnone = 0 then zeroest = 1;
            end;
        if ((Est_for_Spa_Engnone ^= 0) or ((Est_for_Spa_Engnone = 0) and (zeroest = 0))) then do;
            %moe_sumdiff(moe1=tempsum_moe, moe2=MOE_for_Spa_Engnone, moesumdiff=tempsum_moe);
            if Est_for_Spa_Engnone = 0 then zeroest = 1;
            end;
        if ((Est_for_Ind_Engnone ^= 0) or ((Est_for_Ind_Engnone = 0) and (zeroest = 0))) then do;
            %moe_sumdiff(moe1=tempsum_moe, moe2=MOE_for_Ind_Engnone, moesumdiff=tempsum_moe);
            if Est_for_Ind_Engnone = 0 then zeroest = 1;
            end;
        if ((Est_for_API_Engnone ^= 0) or ((Est_for_API_Engnone = 0) and (zeroest = 0))) then do;
            %moe_sumdiff(moe1=tempsum_moe, moe2=MOE_for_API_Engnone, moesumdiff=tempsum_moe);
            if Est_for_API_Engnone = 0 then zeroest = 1;
            end;
        if ((Est_for_oth_Engnone ^= 0) or ((Est_for_oth_Engnone = 0) and (zeroest = 0))) then do;
            %moe_sumdiff(moe1=tempsum_moe, moe2=MOE_for_oth_Engnone, moesumdiff=tempsum_moe);
            if Est_for_oth_Engnone = 0 then zeroest = 1;
            end;
        %moe_pct(estnum=temp_noEngl, moenum=tempsum_moe,
            estdenom=Est_totpop_engl, moedenom=MOE_totpop_engl, moepct=Pct_noEngl_MOE);
        %cvcalc(varname=Pct_noEngl);
        end;
   LABEL    Pct_noEngl     = 'Percent non-English speakers'
            Pct_noEngl_MOE = 'Percent non-English speakers MOE'
            Pct_noEngl_CV  = 'Percent non-English speakers CV'
            ;
   FORMAT   Pct_noEngl     8.3
            Pct_noEngl_MOE 8.3
            Pct_noEngl_CV 10.3
            ;
   DROP num_est num_se denom_est denom_se temp1 pct_se tempsum_moe
        sumdiff1_se sumdiff2_se sumdiff_se temp_noEngl zeroest;
run;

/* Add C17002_povrel and calculate percent below 100% and 150% of poverty */
data Tract_Attributes;
   merge Tract_Attributes
    CensSAS.Table_C17002_povrel_Tract (&obslimit
        keep = StCntyTract Est_tot_pop MOE_tot_pop Est_under50 MOE_under50
                Est_50to99 MOE_50to99 Est_100to124 MOE_100to124 Est_125to149 MOE_125to149
        rename = ( Est_tot_pop=Est_totpop_povrel MOE_tot_pop=MOE_totpop_povrel ) );
   by StCntyTract;
   zeroest = 0; /* flag to indicate a zero estimate has beed used for a series of sums */
   if Est_totpop_povrel ^= 0 then do;
        /* Below 100% of poverty */
        temp_under100 = Est_under50 + Est_50to99;
        Pct_be100pov = 100 * (temp_under100) / Est_totpop_povrel;
        if temp_under100 = 0 then do; /* if both estimates are zero */
            tempsum_moe = MOE_under50; /* use only one zero MOE */
            zeroest = 1; /* set the zero estimate flag */
            end;
        else do;
            %moe_sumdiff(moe1=MOE_under50, moe2=MOE_50to99, moesumdiff=tempsum_moe);
            if (Est_under50 = 0) or (Est_50to99 = 0) then zeroest = 1;
            end;
        %moe_pct(estnum=temp_under100, moenum=tempsum_moe,
            estdenom=Est_totpop_povrel, moedenom=MOE_totpop_povrel, moepct=Pct_be100pov_MOE);
        %cvcalc(varname=Pct_be100pov);
        /* Below 150% of poverty */
        temp_under150 = temp_under100 + Est_100to124 + Est_125to149;
        Pct_be150pov = 100 * (temp_under150) / Est_totpop_povrel;
        if ((Est_100to124 ^= 0) or ((Est_100to124 = 0) and (zeroest = 0))) then do;
            %moe_sumdiff(moe1=tempsum_moe, moe2=MOE_100to124, moesumdiff=tempsum_moe);
            if Est_100to124 = 0 then zeroest = 1;
            end;
        if ((Est_125to149 ^= 0) or ((Est_125to149 = 0) and (zeroest = 0))) then do;
            %moe_sumdiff(moe1=tempsum_moe, moe2=MOE_125to149, moesumdiff=tempsum_moe);
            if Est_125to149 = 0 then zeroest = 1;
            end;
        %moe_pct(estnum=temp_under150, moenum=tempsum_moe,
            estdenom=Est_totpop_povrel, moedenom=MOE_totpop_povrel, moepct=Pct_be150pov_MOE);
        %cvcalc(varname=Pct_be150pov);
        end;
   LABEL    Pct_be100pov     = 'Percent below 100% poverty'
            Pct_be100pov_MOE = 'Percent below 100% poverty MOE'
            Pct_be100pov_CV  = 'Percent below 100% poverty CV'
            Pct_be150pov     = 'Percent below 150% poverty'
            Pct_be150pov_MOE = 'Percent below 150% poverty MOE'
            Pct_be150pov_CV  = 'Percent below 150% poverty CV'
            ;
   FORMAT   Pct_be100pov     8.3
            Pct_be100pov_MOE 8.3
            Pct_be100pov_CV 10.3
            Pct_be150pov     8.3
            Pct_be150pov_MOE 8.3
            Pct_be150pov_CV 10.3
            ;
   DROP num_est num_se denom_est denom_se temp1 pct_se tempsum_moe
        sumdiff1_se sumdiff2_se sumdiff_se temp_under100 temp_under150 zeroest;
run;

/* Add S1701_pov subject table data with percent below poverty */
data Tract_Attributes;
   merge Tract_Attributes
    CensSAS.Table_S1701_pov_Tract (&obslimit
        drop = STATE COUNTY GEO_NAME ) ;
   by StCntyTract;
run;

/* Add NAACCR census tract poverty category: "Census Tr Poverty Indictr", Item #145 */
data Tract_Attributes;
   set Tract_Attributes;
   if      Pctsubj_belowpov = .    then NAACCR_povcat = "9";
   else if Pctsubj_belowpov <  5.0 then NAACCR_povcat = "1";
   else if Pctsubj_belowpov < 10.0 then NAACCR_povcat = "2";
   else if Pctsubj_belowpov < 20.0 then NAACCR_povcat = "3";
   else                                 NAACCR_povcat = "4";
run;

/* Add S2301_employ subject table data with percent unemployed */
data Tract_Attributes;
   merge Tract_Attributes
    CensSAS.Table_S2301_employ_Tract (&obslimit
        drop = STATE COUNTY GEO_NAME ) ;
   by StCntyTract;
run;

/* Add B07001_resmigr and calculate the four percent migration variables */
data Tract_Attributes;
   merge Tract_Attributes
    CensSAS.Table_B07001_resmigr_Tract (&obslimit
        keep = StCntyTract Est_tot_pop MOE_tot_pop
            Est_same_house      MOE_same_house
            Est_from_within_co  MOE_from_within_co
            Est_from_within_st  MOE_from_within_st
            Est_from_within_us  MOE_from_within_us
        rename = ( Est_tot_pop=Est_totpop_migr MOE_tot_pop=MOE_totpop_migr ) );
   by StCntyTract;
   if (Est_totpop_migr ^= .) and (Est_totpop_migr ^= 0) then do;
        /*** Same house ***/
        Pct_same_house = 100 * Est_same_house / Est_totpop_migr;
        /* Calculate the MOE for the percentage */
        %moe_pct(estnum=Est_same_house, moenum=MOE_same_house,
            estdenom=Est_totpop_migr, moedenom=MOE_totpop_migr, moepct=Pct_same_house_MOE);
        %cvcalc(varname=Pct_same_house);
        /*** From within county ***/
        Pct_from_within_co = 100 * Est_from_within_co / Est_totpop_migr;
        /* Calculate the MOE for the percentage */
        %moe_pct(estnum=Est_from_within_co, moenum=MOE_from_within_co,
            estdenom=Est_totpop_migr, moedenom=MOE_totpop_migr, moepct=Pct_from_within_co_MOE);
        %cvcalc(varname=Pct_from_within_co);
        /*** From within state ***/
        Pct_from_within_st = 100 * Est_from_within_st / Est_totpop_migr;
        /* Calculate the MOE for the percentage */
        %moe_pct(estnum=Est_from_within_st, moenum=MOE_from_within_st,
            estdenom=Est_totpop_migr, moedenom=MOE_totpop_migr, moepct=Pct_from_within_st_MOE);
        %cvcalc(varname=Pct_from_within_st);
        /*** From within US ***/
        Pct_from_within_us = 100 * Est_from_within_us / Est_totpop_migr;
        /* Calculate the MOE for the percentage */
        %moe_pct(estnum=Est_from_within_us, moenum=MOE_from_within_us,
            estdenom=Est_totpop_migr, moedenom=MOE_totpop_migr, moepct=Pct_from_within_us_MOE);
        %cvcalc(varname=Pct_from_within_us);
        end;
   LABEL    Pct_same_house         = 'Percent in same house 1 year ago'
            Pct_same_house_MOE     = 'Percent in same house 1 year ago MOE'
            Pct_same_house_CV      = 'Percent in same house 1 year ago CV'
            Pct_from_within_co     = 'Percent moved within same county'
            Pct_from_within_co_MOE = 'Percent moved within same county MOE'
            Pct_from_within_co_CV  = 'Percent moved within same county CV'
            Pct_from_within_st     = 'Percent moved from different county within state'
            Pct_from_within_st_MOE = 'Percent moved from different county within state MOE'
            Pct_from_within_st_CV  = 'Percent moved from different county within state CV'
            Pct_from_within_us     = 'Percent moved from different state within US'
            Pct_from_within_us_MOE = 'Percent moved from different state within US MOE'
            Pct_from_within_us_CV  = 'Percent moved from different state within US CV'
            ;
   FORMAT   Pct_same_house         8.3
            Pct_same_house_MOE     8.3
            Pct_same_house_CV     10.3
            Pct_from_within_co     8.3
            Pct_from_within_co_MOE 8.3
            Pct_from_within_co_CV 10.3
            Pct_from_within_st     8.3
            Pct_from_within_st_MOE 8.3
            Pct_from_within_st_CV 10.3
            Pct_from_within_us     8.3
            Pct_from_within_us_MOE 8.3
            Pct_from_within_us_CV 10.3
            ;
   DROP num_est num_se denom_est denom_se temp1 pct_se;
run;

/* Sort and check for duplicates: */
proc sort data=Tract_Attributes nodupkey out=CensSAS.Tract_Attributes_prelim;
   by STUSAB StCntyTract;
run;

/* Just Montgomery County, MD: for testing
data CensSAS.Tract_Attributes_prelim_MontCoMD;
   set CensSAS.Tract_Attributes_prelim;
   if STUSAB = 'MD';
   if COUNTY = '031';
run;
*/

/* Counts by state */
proc freq data=CensSAS.Tract_Attributes_prelim;
   table STUSAB;
run;

/* Number of distinct values for each variable */
ods select nlevels;
proc freq data=CensSAS.Tract_Attributes_prelim nlevels;
   tables STUSAB;
run;

/* Basic descriptive stats for calculated percentages, MOEs, and CVs */
proc means data=CensSAS.Tract_Attributes_prelim nolabels n min mean max stddev cv nmiss ;
   var
    Pct_sampled
    Pct_nonwhite        Pct_nonwhite_MOE        Pct_nonwhite_CV
    Pct_Hispanic        Pct_Hispanic_MOE        Pct_Hispanic_CV
    Pct_minority        Pct_minority_MOE        Pct_minority_CV
    Pct_forborn         Pct_forborn_MOE         Pct_forborn_CV
    Pctsubj_highsch     Pctsubj_highsch_MOE     Pctsubj_highsch_CV
    Pctsubj_notHS       Pctsubj_notHS_MOE       Pctsubj_notHS_CV
    Pctsubj_college     Pctsubj_college_MOE     Pctsubj_college_CV
    Pctsubj_lingiso     Pctsubj_lingiso_MOE     Pctsubj_lingiso_CV
    Pct_noEngl          Pct_noEngl_MOE          Pct_noEngl_CV
    Pct_be100pov        Pct_be100pov_MOE        Pct_be100pov_CV
    Pct_be150pov        Pct_be150pov_MOE        Pct_be150pov_CV
    Pctsubj_belowpov    Pctsubj_belowpov_MOE    Pctsubj_belowpov_CV
    Pctsubj_unemploy    Pctsubj_unemploy_MOE    Pctsubj_unemploy_CV
    Pct_same_house      Pct_same_house_MOE      Pct_same_house_CV
    Pct_from_within_co  Pct_from_within_co_MOE  Pct_from_within_co_CV
    Pct_from_within_st  Pct_from_within_st_MOE  Pct_from_within_st_CV
    Pct_from_within_us  Pct_from_within_us_MOE  Pct_from_within_us_CV
    ;
run;

proc freq data=CensSAS.Tract_Attributes_prelim;
    tables NAACCR_povcat;
run;

ods pdf close;

